@@ -1,23 +1,43 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-##try:
-##    from PyQt4.QtGui import *
-##except ImportError:
-from qt import *
+import logging, os
+import logging.handlers
+LOG_FILENAME = os.path.join(os.environ['HOME'],'epigrass_errors.out')
+epigrassLogger = logging.getLogger('epigrassLogger')
+epigrassLogger.setLevel(logging.ERROR)
+handler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=20000, backupCount=1)
+epigrassLogger.addHandler(handler)
+
+try:
+    from PyQt4 import QtCore, QtGui
+    from PyQt4.QtGui import *
+except ImportError: 
+    epigrassLogger.error("Please install PyQT 4")
+    print "Please install PyQT 4"
+
 from Epigrass.manager import *
-from threading import *
-from Epigrass.cpanel import MainPanel
-from Epigrass.about import aboutDialog
-import os,sys,ConfigParser, string, copy, commands,getpass
+import threading,  subprocess,  glob
+from Epigrass.Ui_cpanel4new import Ui_MainWindow
+from Epigrass.Ui_about4 import Ui_aboutDialog as aboutDialog
+import sys,ConfigParser, string, copy, commands,getpass
 import Epigrass.epiplay as epi
-from Epigrass import spread
-#from pylabQtcanvas import MyMplCanvas as canvas
+from Epigrass import spread,  dgraph
+try:
+    import psyco
+    psyco.full()
+except:
+    epigrassLogger.info("Install Psyco for better performance." )
+    pass
 
 
-class MainPanel_Impl(MainPanel):
-
-    def __init__(self,parent = None,name = None,fl = 0):
-        
+class MainWindow_Impl(QtGui.QMainWindow, Ui_MainWindow):
+    sequenceNumber = 1
+    windowList = []
+    def __init__(self):
+        QtGui.QMainWindow.__init__(self, None)
+        self.app=app
+        self.QtCore = QtCore
+        self.setupUi(self)
         #determining the user's home directory
         home = os.curdir                        # Default
         if 'HOME' in os.environ:
@@ -34,6 +54,7 @@ class MainPanel_Impl(MainPanel):
         self.epigrassrc = os.path.join(home, ".epigrassrc")
         # set Translation
         self.curdir = os.getcwd()
+        self.rootdir = os.getcwd()
         if os.access(self.epigrassrc,os.F_OK):
             try:
                 self.conf = self.loadRcFile(self.epigrassrc)
@@ -42,29 +63,31 @@ class MainPanel_Impl(MainPanel):
                 lang = ''
             #print lang
         else: lang = ''
-        tr = QTranslator(app)
+        tr = QtCore.QTranslator(app)
         loadLang(app,tr,lang)
-        
-        MainPanel.__init__(self,parent,name,fl)
+       
         # Overload connections
-        self.connect(self.editButton,SIGNAL("released()"),self.editScript)
-        self.connect(self.chooseButton,SIGNAL("released()"),self.chooseScript)
-        self.connect(self.buttonExit,SIGNAL("released()"),self.onExit)
-        self.connect(self.buttonRun,SIGNAL("released()"),self.onRun)
-        self.connect(self.buttonHelp,SIGNAL("released()"),self.onHelp)
-        self.connect(self.dbBackup,SIGNAL("released()"),self.onDbBackup)
-        self.connect(self.dbInfo,SIGNAL("released()"),self.onDbInfo)
-        self.connect(self.repOpen,SIGNAL("released()"),self.onRepOpen)
-        self.connect(self.playButton,SIGNAL("released()"),self.onPlayButton)
-        self.connect(self.playButton_2D,SIGNAL("released()"),self.onPlayButton_2D)
-        self.connect(self.dbscanButton,SIGNAL("released()"),self.onVisual)
-        self.connect(self.consensusButton,SIGNAL("released()"),self.onConsensus)
-        self.connect(self.tableList,SIGNAL("activated(int)"),self.getVariables)
-        self.connect(self.dbType,SIGNAL("activated(int)"),self.setBackend)
-        #check if rc file exists if not, creates one
+        self.connect(self.editButton,QtCore.SIGNAL("released()"),self.editScript)
+        self.connect(self.chooseButton,QtCore.SIGNAL("released()"),self.chooseScript)
+        self.connect(self.buttonExit,QtCore.SIGNAL("released()"),self.onExit)
+        self.connect(self.buttonRun,QtCore.SIGNAL("released()"),self.onRun)#Thread)
+        self.connect(self.buttonHelp,QtCore.SIGNAL("released()"),self.onHelp)
+        self.connect(self.dbBackup,QtCore.SIGNAL("released()"),self.onDbBackup)
+        self.connect(self.dbInfo,QtCore.SIGNAL("released()"),self.onDbInfo)
+#        self.connect(self.repOpen,QtCore.SIGNAL("released()"),self.onRepOpen)
+        self.connect(self.playButton,QtCore.SIGNAL("released()"),self.onPlayButton)
+#        self.connect(self.playButton_2D,QtCore.SIGNAL("released()"),self.onPlayButton_2D)
+        self.connect(self.dbscanButton,QtCore.SIGNAL("released()"),self.onVisual)
+        self.connect(self.consensusButton,QtCore.SIGNAL("released()"),self.onConsensus)
+        self.connect(self.tableList,QtCore.SIGNAL("activated(int)"),self.getVariables)
+        self.connect(self.dbType,QtCore.SIGNAL("activated(int)"),self.setBackend)
+        QtCore.QMetaObject.connectSlotsByName(self)
+        self.upGUITimer = QtCore.QTimer()
+        self.connect(self.upGUITimer, QtCore.SIGNAL("timeout()"), app.processEvents)
+        self.upGUITimer.start(100)
         
         usern = getpass.getuser() #Get the user name
-        
+        #check if rc file exists if not, creates one
         if not os.access(self.epigrassrc,os.F_OK):
             self.initRc()
 
@@ -73,6 +96,20 @@ class MainPanel_Impl(MainPanel):
             self.fillGui(self.conf)
         self.sim = None
             
+    def openGraphDisplay(self, shp='', namefield='', geocfield='', nlist=[], elist=[]):
+        """
+        Starts the Qt map display
+        shp: shapefile fname
+        """
+        self.graphDisplay = dgraph.MapWindow()
+        self.windowList.append(self.graphDisplay)
+        #self.graphDisplay.move(self.x()+40, self.y()+40)
+        if shp:
+            self.graphDisplay.drawMap(shp, namefield, geocfield)
+        else:
+            self.graphDisplay.drawGraph(nlist, elist)
+        self.graphDisplay.show()
+    
     def initRc(self):
         """
         Initializes the epigrassrc file.
@@ -157,11 +194,15 @@ class MainPanel_Impl(MainPanel):
         Fill the gui fields from configuration dictionary conf.
         """
         if self.conf['settings.language'] == 'pt_BR':
-            self.langCombo.setCurrentItem(1)
+            self.langCombo.setCurrentIndex(1)
         elif self.conf['settings.language'] == 'fr':
-            self.langCombo.setCurrentItem(2)
+            self.langCombo.setCurrentIndex(2)
+        elif self.conf['settings.language'] == 'ru':
+            self.langCombo.setCurrentIndex(3)
+        elif self.conf['settings.language'] == 'es':
+            self.langCombo.setCurrentIndex(4)
         else:
-            self.langCombo.setCurrentItem(0)
+            self.langCombo.setCurrentIndex(0)
         try:
             self.scriptNameEdit.setText(conf['model.script'])
             self.hostnEdit.setText(conf['database.host'])
@@ -175,11 +216,7 @@ class MainPanel_Impl(MainPanel):
             QMessageBox.information(None,
                 self.trUtf8("Syntax Error"),
                 self.trUtf8("""Please check file .epigrassrc for missing %s keyword
-                from section %s """%(V[1],V[0])),
-                None,
-                None,
-                None,
-                0, -1)
+                from section %s """%(V[1],V[0])))
 ##            usern = pwd.getpwuid(os.getuid())[0] #Get the user name
 ##            os.system('rm /home/'+usern+'.epigrassrc')
 ##            self.initRc()
@@ -195,10 +232,7 @@ class MainPanel_Impl(MainPanel):
                 QMessageBox.information(None,
                     self.trUtf8("Incomplete Configuration"),
                     self.trUtf8("""Please enter a value for %s."""%i[0]),
-                    self.trUtf8("&OK"),
-                    None,
-                    None,
-                    0, -1)
+                    self.trUtf8("&OK"))
                 return 0
         return 1
 
@@ -216,10 +250,7 @@ class MainPanel_Impl(MainPanel):
                 self.trUtf8("Editor or Script not selected"),
                 self.trUtf8("""Please make sure you have selected both
 an editor and your model's script."""),
-                self.trUtf8("&OK"),
-                None,
-                None,
-                0, -1)
+                self.trUtf8("&OK"))
 
         
         
@@ -228,11 +259,19 @@ an editor and your model's script."""),
         starts the file selction dialog for the script.
         """
         scrname = QFileDialog.getOpenFileName(\
-                    QString.null,
-                    self.trUtf8("*.epg"),
-                    None, None,
-                    self.trUtf8("Select your Model's Script"),
-                    None, 1)
+            None,
+            self.trUtf8("Select your Model's Script"),
+            QtCore.QString(),
+            self.trUtf8("*.epg"),
+            None)
+
+
+#        scrname = QFileDialog.getOpenFileName(\
+#                    QtCore.QString.null,
+#                    self.trUtf8("*.epg"),
+#                    None, None,
+#                    self.trUtf8("Select your Model's Script"),
+#                    None, 1)
         self.scriptNameEdit.setText(scrname)
         self.conf['model.script'] = scrname
     
@@ -252,107 +291,107 @@ an editor and your model's script."""),
         os.chdir(os.path.split(self.conf['model.script'])[0])
         #print os.getcwd()
         
-        if int(self.langCombo.currentItem()) == 1:
+        if int(self.langCombo.currentIndex()) == 1:
             self.conf['settings.language'] = 'pt_BR'
-        elif int(self.langCombo.currentItem()) == 2:
+        elif int(self.langCombo.currentIndex()) == 2:
             self.conf['settings.language'] = 'fr'
+        elif int(self.langCombo.currentIndex()) == 3:
+            self.conf['settings.language'] = 'ru'
+        elif int(self.langCombo.currentIndex()) == 4:
+            self.conf['settings.language'] = 'es'
         else:
             self.conf['settings.language'] = 'en'
-
-    def onRunFuture(self):
-        """
-        Run the simulation on a separate thread
-        """
-        return Future(self.onRun)
+    
+        
+    
     def onRun(self):
         """
         starts the simulation when the run button is pressed
         """
-        self.tabWidget.setCurrentPage(2)
-        app.processEvents(1000)
+        self.stepLCD.display(0)
+        self.tabWidget.setCurrentIndex(2)
         self.readGui()
         self.updateRc()
         if self.checkConf():
-            if not self.dbType.currentItem():
+            if not self.dbType.currentIndex():
                 if not self.pwEdit.text():
                     QMessageBox.warning(None,
                         self.trUtf8("Missing Database Password"),
-                        self.trUtf8("""Please enter password for the Mysql Database."""),
-                        QString.null,
-                        QString.null,
-                        QString.null,
-                        0, -1)
+                        self.trUtf8("""Please enter password for MySQL database."""))
                     return
-                    
+            self.buttonRun.setEnabled(0)
             self.sim = S = simulate(fname=self.conf['model.script'],host=self.conf['database.host'],port=int(self.conf['database.port']),
-                        db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(self.dbType.currentText().lower()))
+                        db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(self.dbType.currentText()).lower())
             S.gui = self
+#            if S.shapefile:
+#                self.openGraphDisplay(S.shapefile[0], S.shapefile[1],S.shapefile[2] )
+            
+            self.RT = RunThread(S)
+#            QtCore.QObject.connect(self.RT,QtCore.SIGNAL("drawStep"), self.graphDisplay.drawStep)
             if not S.replicas:
-                S.start()
-                app.processEvents(1000)
-                dot = spread.Spread(self.sim.g, self.sim.outdir,self.sim.encoding)
+                self.RT.start()
                 
-                if S.Rep:
-                    rep = Rp.report(S)
-                    self.textEdit1.insertParagraph('Report generation started.',-1)
-                    app.processEvents(1000)
-                    rep.Assemble(S.Rep)
+                
+                self.buttonRun.setEnabled(1)
             else: #Repeated runs 
                 self.repRuns(S)
+                self.buttonRun.setEnabled(1)
                 
             
             # In case of a batch
             if S.Batch:
-                self.textEdit1.insertParagraph('Simulation Started.',-1)
-                app.processEvents(1000)
+                self.textEdit1.insertPlainText('Simulation Started.')
+                
                 # run the batch list
                 for i in S.Batch:
                     #Makes sure it comes back to original directory before opening models in the batch list
                     os.chdir(self.sim.dir)
                     # Generates the simulation object        
                     self.sim = T = simulate(fname=i,host=self.conf['database.host'],port=int(self.conf['database.port']),
-                        db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(self.dbType.currentText().lower()))
+                        db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(self.dbType.currentText()).lower())
                     T.gui = self
                     print 'starting model %s'%i
                     T.start()  # Start the simulation 
-                    app.processEvents(1000)
-                    if S.Rep: #Start report generation
-                        rep = Rp.report(T)
-                        self.textEdit1.insertParagraph('Report generation started.',-1)
-                        app.processEvents(1000)
-                        rep.Assemble(S.Rep)
 
-            self.textEdit1.insertParagraph('Done!',-1)
+            self.textEdit1.insertPlainText('Done!')
+            self.buttonRun.setEnabled(1)
             #print 'Agora...'
-            #spdisp = spread.Spread(self.sim.g)
+            spread.Spread(self.sim.g, self.sim.outdir,self.sim.encoding)
+            
             #spdisp.display()
         else:
+            self.buttonRun.setEnabled(1)
             return
+            
     
     def repRuns(self,S):
         """
         Do repeated runs
         """
-        if S.randomize_seeds:
-            randseed = 1
-        else:
-            randseed = 0
-        seeds = S.randomizeSeed()
-        for i in range(S.replicas):
+        nseeds= S.seed[0][2] #number o individual to be used as seeds
+        randseed=S.randomize_seeds  
+        print "replicas type", randseed
+        if randseed: 
+            seeds = S.randomizeSeed(randseed)
+        reps = S.replicas
+        for i in xrange(reps):
             print "Starting replica number %s"%i
-            self.textEdit1.insertParagraph("Starting replica number %s"%i,-1)
+            self.textEdit1.insertPlainText("Starting replica number %s"%i)
             self.sim = S = simulate(fname=self.conf['model.script'],host=self.conf['database.host'],port=int(self.conf['database.port']),
-                db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(self.dbType.currentText().lower()))
+                db='epigrass',user=self.conf['database.user'], password=str(self.pwEdit.text()),backend=str(str(self.dbType.currentText()).lower()))
+            S.gui = self
             if randseed:
-                S.setSeed(seeds[i])
+                S.setSeed(seeds[i], nseeds)
             S.round = i
+            S.shpout = False
             S.start()
-            app.processEvents(1000)
-            if S.Rep: #Generate report if necessary
-                rep = Rp.report(S)
-                self.textEdit1.insertParagraph('Report generation started.',-1)
-                app.processEvents(1000)
-                rep.Assemble(S.Rep)
+            del S,  self.sim
+            
+#            if S.Rep: #Generate report if necessary
+#                rep = Rp.report(S)
+#                self.textEdit1.insertPlainText('Report generation started.')
+#                rep.Assemble(S.Rep)
+#            del S
     
     def onDbBackup(self):
         """
@@ -363,10 +402,7 @@ an editor and your model's script."""),
                 self.trUtf8("Non-local Database Server"),
                 self.trUtf8("""Currently, the database backup function only
                 works on local database servers."""),
-                self.trUtf8("&OK"),
-                None,
-                None,
-                0, -1)
+                self.trUtf8("&OK"))
 
 
         os.system('mysqldump -u %s -p%s --opt epigrass > epigrass.sql'%(str(self.uidEdit.text()),self.pwEdit.text()))
@@ -378,10 +414,7 @@ to a file named "epigrass.sql".
 This file is in you current working directory.
 To restore the database type:
 epigrass.sql > mysql"""),
-            self.trUtf8("&OK"),
-            None,
-            None,
-            0, -1)
+            self.trUtf8("&OK"))
     
     def onDbInfo(self):
         pass
@@ -390,21 +423,20 @@ epigrass.sql > mysql"""),
         """
         Opens the userguide
         """
+        aboutD = QtGui.QDialog()
         ab = aboutDialog()
-        ab.show()
-        ab.exec_loop()
-        if os.path.exists('/usr/share/epigrass/docs/userguide.pdf'):
-            try:
-                os.system('%s /usr/share/epigrass/docs/userguide.pdf'%str(self.pdfEdit.text()))
-            except:
-                QMessageBox.warning(None,
-                    self.trUtf8("Help not available"),
-                    self.trUtf8("""Could not open user guide.
-    Please make sure your chosen PDF viewer is installed."""),
-                    self.trUtf8("&OK"),
-                    None,
-                    None,
-                    0, -1)
+        ab.setupUi(aboutD)
+        aboutD.show()
+        aboutD.exec_()
+#        if os.path.exists('/usr/share/epigrass/docs/Epigrass.pdf'):
+#            try:
+#                os.system('%s /usr/share/epigrass/docs/Epigrass.pdf'%str(self.pdfEdit.text()))
+#            except:
+#                QMessageBox.warning(None,
+#                    self.trUtf8("Help not available"),
+#                    self.trUtf8("""Could not open user guide.
+#    Please make sure your chosen PDF viewer is installed."""),
+#                    self.trUtf8("&OK"))
 
     def onRepOpen(self):
         """
@@ -417,35 +449,51 @@ epigrass.sql > mysql"""),
                 self.trUtf8("No Report"),
                 self.trUtf8("""Could not open the report.
 Make sure you have generated it."""),
-                self.trUtf8("&OK"),
-                None,
-                None,
-                0, -1)
+                self.trUtf8("&OK"))
             
     
+    
     def onVisual(self):
         """
         Scan the epigrass database an shows available simulations.
         """
-        if not self.dbType.currentItem():
+        basedir = self.rootdir
+        if not self.dbType.currentIndex():
             if not self.pwEdit.text():
                 QMessageBox.warning(None,
                     self.trUtf8("Missing Database Password"),
-                    self.trUtf8("""Please enter the password for the Epigrass database in the first tab."""),
-                    self.trUtf8("&OK"),
-                    QString.null,
-                    QString.null,
-                    0, -1)
+                    self.trUtf8("""Please enter the password for the MySQL database in the first tab."""))
                 return
+        # for SQLite databases check for the existence os the database file.
+        if self.dbType.currentIndex() == 1: 
+            if not os.path.exists('Epigrass.sqlite'):
+                basedir = str(QFileDialog.getExistingDirectory(\
+                    None,
+                    self.trUtf8("No SQLite database found. Please select a new directory."),
+                    QtCore.QString(),
+                    QFileDialog.Options(QFileDialog.ShowDirsOnly)))
+            if not glob.glob(basedir+'*.sqlite'):
+                QMessageBox.information(None,
+                    self.trUtf8("No Database found"),
+                    self.trUtf8("""No file ending with ".sqlite" was found. 
+Please try a different  directory."""),
+                    QMessageBox.StandardButtons(\
+                        QMessageBox.Ok),
+                    QMessageBox.Ok)
+            else:
+                os.chdir(basedir)
+                
         self.Display=epi.viewer(host=str(self.hostnEdit.text()),port=int(str(self.portEdit.text())),
-                        db='epigrass',user=str(self.uidEdit.text()), pw=str(self.pwEdit.text()),backend=self.conf['database.backend'])
+                            db='epigrass',user=str(self.uidEdit.text()), pw=str(self.pwEdit.text()),backend=self.conf['database.backend'], gui=self)
+        os.chdir(self.curdir)
+
         for s in self.Display.tables:
-            if not s.startswith('adj_'):
-                self.tableList.insertItem(s)
+            if s.endswith('_meta'):
+                self.tableList.insertItem(0, s[:-5])
         #check for available maps
         maplist = [i for i in os.listdir(os.getcwd()) if i.endswith('.shp')]
         for m in maplist:
-            self.mapList.insertItem(m)
+            self.mapList.insertItem(0, m)
     
     def getVariables(self):
         """
@@ -456,93 +504,47 @@ Make sure you have generated it."""),
         self.vars = self.Display.getFields(table)
         for s in self.vars:
             if s not in ['id','name','geocode','lat','longit','time']:
-                self.variableList.insertItem(s)
+                self.variableList.insertItem(0, s)
+        #TODO: read meta-info from table and show in the tooltip
+#        self.tableList.setToolTip('')
     
     def onPlayButton(self):
         """
         Calls the epiplay module to replay the epidemic from a database table.
         """
+        
         #get variable to animate and its position in the database
         var = str(self.variableList.currentText())
         pos = self.vars.index(var)
         r = self.rateSpinBox.value() 
         table = str(self.tableList.currentText())
-        mapa = str(self.mapList.currentText())
+        if self.Display.shapefile:
+            mapa = self.Display.shapefile[0]
+        else:
+            mapa =None
         modname = table.split('_')[0] #self.sim.modelName.split('/')[-1]
+        #change the the outdata directory
+        if not os.path.split(os.getcwd())[1].startswith("outdata"):
+            os.chdir("outdata-"+modname)
         nodes,am = self.Display.readNodes(modname, table)
         if not nodes:
             QMessageBox.warning(None,
                 self.trUtf8("Empty Table"),
                 self.trUtf8("""You have selected an empty table.
-Please select another table from the menu."""),
-                QString.null,
-                QString.null,
-                QString.null,
-                0, -1)
+Please select another table from the menu."""))
             return
 
         numbnodes = len(nodes)
         data = self.Display.readData(table)
         edata = self.Display.readEdges(table)
+        os.chdir(self.rootdir)
         numbsteps = len(data)/numbnodes
         self.Display.viewGraph(nodes,am,var,mapa)
         self.Display.anim(data,edata,numbsteps,pos,r)
         #Future(self.Display.keyin,data,edata,numbsteps,pos,r)
-        self.Display.keyin(data,edata,numbsteps,pos,r)
+        #self.Display.keyin(data,edata,numbsteps,pos,r)
+    
     
-    def onPlayButton_2D(self):
-        """
-        Calls the epiplay module to replay the epidemic from a database table.
-        """
-        #get variable to animate and its position in the database
-        var = str(self.variableList.currentText())
-        pos = self.vars.index(var)
-        r = self.rateSpinBox.value() 
-        table = str(self.tableList.currentText())
-        mapa = str(self.mapList.currentText())
-        if mapa in ['No map','Nenhum mapa','Pas de carte']:
-            QMessageBox.critical(None,
-                self.trUtf8("No Map!"),
-                self.trUtf8("""You must select a map for a 2D animation!"""),
-                self.trUtf8("&Retry"),
-                QString.null,
-                QString.null,
-                0, -1)
-            return
-
-        modname = table.split('_')[0] #self.sim.modelName.split('/')[-1]
-        nodes,am = self.Display.readNodes(modname, table)
-        ans = QInputDialog.getText(\
-            self.trUtf8("Geocode Variable"),
-            self.trUtf8("Enter the variable name containing the geocode."),
-            QLineEdit.Normal)
-        geocfield = str(ans[0])
-        if not ans[1]:
-            return
-        if not nodes:
-            QMessageBox.warning(None,
-                self.trUtf8("Empty Table"),
-                self.trUtf8("""You have selected an empty table.
-Please select another table from the menu."""),
-                QString.null,
-                QString.null,
-                QString.null,
-                0, -1)
-            return
-
-        numbnodes = len(nodes)
-        data = self.Display.readData(table)
-        edata = self.Display.readEdges(table)
-        numbsteps = len(data)/numbnodes
-        plotwindow = QMainWindow(None,"Plot window", Qt.WType_TopLevel | Qt.WDestructiveClose)
-        plot_widget = QWidget(plotwindow, "plot widget")
-        l = QVBoxLayout(plot_widget)
-        can = canvas(plot_widget,width=5,height=4,dpi=300)
-        l.addWidget(can)
-        plot_widget.setFocus()
-        plotwindow.show()
-        ax,pl = self.Display.viewGraph2D(mapa, geocfield,can)
-        self.Display.anim2D(data,nodes,numbsteps,pos,ax,pl)
         
     def onConsensus(self):
         """
@@ -570,7 +572,7 @@ Please select another table from the menu."""),
         """
         self.backend = self.conf['database.backend']= str(self.dbType.currentText()).lower()
         #print self.backend
-        if self.dbType.currentItem():
+        if self.dbType.currentIndex():
             self.dbSpecGroupBox.setEnabled(0)
             self.dbBackup.setEnabled(0)
         else:
@@ -581,9 +583,6 @@ Please select another table from the menu."""),
         """
         Close the gui
         """
-        if self.sim:
-            if self.sim.g.gr:
-                self.sim.g.clearVisual()
         self.close()
         
 class Future:
@@ -661,26 +660,48 @@ def loadLang(app,tr,lang):
     if lang == 'pt_BR':
         tr.load('manager_pt_BR','.')
         app.installTranslator(tr)
-    if lang == 'fr':
+    elif lang == 'fr':
         tr.load('epigrass_fr','.')
         app.installTranslator(tr)
+    elif lang == 'es':
+        tr.load('epigrass_es','.')
+        app.installTranslator(tr)
+    elif lang == 'ru':
+        tr.load('epigrass_ru_RU','.')
+        app.installTranslator(tr)
     else:
         pass
         
 def main():
     global app
-    app = QApplication(sys.argv)
-    QObject.connect(app,SIGNAL("lastWindowClosed()"),app,SLOT("quit()"))
-    w = MainPanel_Impl()
-    app.setMainWidget(w)
+    app = QtGui.QApplication(sys.argv)
+    w = MainWindow_Impl()
     w.show()
-    app.exec_loop()
+    sys.exit(app.exec_())
+class RunThread(QtCore.QThread):
+    """
+    Worker Thread to run the simulation in a separate thread in order to allow the updating of the GUI to take place
+    """
+    def __init__(self,sim,  parent=None):
+        QtCore.QThread.__init__(self, parent)
+        self.mutex = QtCore.QMutex()
+        self.condition = QtCore.QWaitCondition()
+        self.sim = sim
+    def __del__(self):
+        self.mutex.lock()
+        self.condition.wakeOne()
+        self.mutex.unlock()
+        self.wait()
+    def go(self):
+        locker = QtCore.QMutexLocker(self.mutex)
+        self.start()
+    def run(self):
+        self.sim.start()
+        self.mutex.lock()
+        self.condition.wait(self.mutex)
+        self.mutex.unlock()
 
 if __name__ == "__main__":
     main()
-##    app = QApplication(sys.argv)
-##    QObject.connect(app,SIGNAL("lastWindowClosed()"),app,SLOT("quit()"))
-##    w = MainPanel_Impl()
-##    app.setMainWidget(w)
-##    w.show()
-##    app.exec_loop()
+    
+    
